from cattrs.converters import Converter

from django.conf import settings

from .register_hooks import (
    register_all_unstructure_hooks,
    register_structure_hooks,
    register_all_empty_unstructure_hooks,
)

converter = Converter()


register_structure_hooks(converter)
register_all_unstructure_hooks(converter)

if getattr(settings, "DCF_EMPTY_HOOKS", False):
    register_all_empty_unstructure_hooks(converter)



import pytest

from attrs import define

from django_cattrs_fields.converters import converter
from django_cattrs_fields.fields import CharField, IntegerField

from tests.books.models import Human


@define
class HumanData:
    name: CharField
    age: IntegerField


@pytest.fixture
def seed(db):
    for i in range(5):
        Human.objects.create(name=f"a{i}", age=i)


def test_structure(seed):
    data = Human.objects.get(id=1)

    struct = converter.structure(data, HumanData)

    man = converter.structure({"name": data.name, "age": data.age}, HumanData)

    assert struct == man
    assert isinstance(struct.name, str)
    assert struct.name == data.name


def test_unstructure(seed):
    data = Human.objects.get(id=1)

    struct = converter.structure(data, HumanData)

    assert converter.unstructure(struct) == {"name": data.name, "age": data.age}



from django.db import models


class Book(models.Model):  # noqa: DJ008
    pdf = models.FileField(upload_to="media/", null=True)


class Human(models.Model):  # noqa: DJ008
    name = models.CharField()
    age = models.IntegerField()
